@@ -13,11 +13,13 @@ nox.options.stop_on_first_error = True
 nox.options.reuse_existing_virtualenvs = True
 
 
-BLACK_SPEC = "black>=22.3.0"
+BLACK_SPEC = "black==22.12.0"
 ISORT_SPEC = "isort==5.6.3"
+MYPY_SPEC = "mypy==0.991"
 PIP_SPEC = "pip>=21.3"
 PYTEST_MOCK_SPEC = "pytest-mock==3.3.1"
 PYTEST_SPEC = "pytest==7.2"
+PYTEST_XDIST_SPEC = "pytest-xdist==3.1.0"
 
 SPHINX_SOURCE_DIR = "docs"
 SPHINX_OUTPUT_DIR = "docs/_build"
@@ -109,7 +111,7 @@ def mypy(session):
     else:
         session.install(".")
 
-    session.install("mypy", PYTEST_SPEC)
+    session.install(MYPY_SPEC, PYTEST_SPEC)
     session.run("python", "-m", "mypy", "-p", "acconeer.exptool.a121")
     session.run("python", "-m", "mypy", "-p", "acconeer.exptool.app.new")
     session.run("python", "-m", "mypy", "-p", "acconeer.exptool.setup")
@@ -172,11 +174,11 @@ def docs_autobuild(session):
 
 
 @nox.session
-@nox.parametrize("python", ["3.7", "3.8", "3.9", "3.10"])
+@nox.parametrize("python", ["3.7", "3.8", "3.9", "3.10", "3.11"])
 def test(session):
     args = Parser().parse_args(session.posargs)
 
-    install_deps = {PYTEST_SPEC}
+    install_deps = {PYTEST_SPEC, PYTEST_XDIST_SPEC}
     install_extras = set()
     pytest_commands = []
 
@@ -187,8 +189,8 @@ def test(session):
         install_extras |= {"algo"}
         pytest_commands.extend(
             [
-                ["-p", "no:pytest-qt", "tests/unit"],
-                ["-p", "no:pytest-qt", "tests/processing"],
+                ["-n", "auto", "-p", "no:pytest-qt", "tests/unit"],
+                ["-n", "auto", "-p", "no:pytest-qt", "tests/processing"],
             ]
         )
 
