@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 import enum
 import json
 import logging
@@ -244,6 +247,9 @@ class JsonProtocolStreamingServer(JsonProtocolBase):
         for config_key, cmd_key in CONFIG_TO_CMD_KEY_MAP.items():
             config_val = getattr(config, config_key, None)
 
+            if self._mode == Mode.IQ and config_key == "sampling_mode":
+                continue
+
             if config_val is None:
                 continue
 
@@ -343,6 +349,9 @@ class JsonProtocolExplorationServer(JsonProtocolBase):
             if config_key in ["sensor", "update_rate", "repetition_mode"]:
                 continue
 
+            if self._mode == Mode.IQ and config_key == "sampling_mode":
+                continue
+
             if config_val is None:
                 continue
 
@@ -502,7 +511,7 @@ class SocketClient(BaseClient):
 
         msg = self._protocol.get_version()
         if msg:
-            startstr = "server version v"
+            startstr = "server version "
             if not msg.startswith(startstr):
                 log.warning("server version unknown")
                 return info
@@ -515,7 +524,7 @@ class SocketClient(BaseClient):
         else:
             self._protocol = JsonProtocolExplorationServer(self._link, self.squeeze)
             system_info = self._protocol.get_system_info()
-            info.update(decode_version_str(system_info["rss_version"][1:]))
+            info.update(decode_version_str(system_info["rss_version"]))
             info["sensor"] = system_info["sensor"]
             info["board_sensor_count"] = system_info["sensor_count"]
             info["hw"] = system_info["hw"]
@@ -591,6 +600,7 @@ CONFIG_TO_CMD_KEY_MAP = {
     "noise_level_normalization": "noise_level_normalization",
     "maximize_signal_attenuation": "maximize_signal_attenuation",
     "running_average_factor": "running_average_factor",
+    "sampling_mode": "sampling_mode",
     "sweeps_per_frame": "sweeps_per_frame",
     "sweep_rate": "sweep_rate",
     "tx_disable": "tx_disable",
