@@ -29,6 +29,12 @@ class ExampleArgumentParser(ArgumentParser):
             nargs="?",
             const=True,
         )
+        server_group.add_argument(
+            "--mock",
+            dest="mock",
+            default=None,
+            action="store_true",
+        )
 
         verbosity_group = self.add_mutually_exclusive_group(required=False)
         verbosity_group.add_argument(
@@ -55,5 +61,5 @@ def get_client_args(namespace: Namespace) -> Dict[str, Any]:
     :returns: dictionary with client-related keyword-arguments.
     """
 
-    CLIENT_RELATED_KEYS = ["ip_address", "serial_port", "usb_device"]
+    CLIENT_RELATED_KEYS = ["ip_address", "serial_port", "usb_device", "mock"]
     return {k: getattr(namespace, k) for k in CLIENT_RELATED_KEYS if hasattr(namespace, k)}
