@@ -3,5 +3,7 @@
 
 from ._factory import get_exploration_protocol
 from ._latest import ExplorationProtocol, ExplorationProtocolError
-from ._v0_4_1 import ExplorationProtocol_0_4_1
+from ._no_5_2_mhz import ExplorationProtocol_No_5_2MHz_PRF
+from ._no_15_6_mhz import ExplorationProtocol_No_15_6MHz_PRF
+from ._no_calibration_reuse import ExplorationProtocol_NoCalibrationReuse
 from .server_error import ServerError
