@@ -8,7 +8,7 @@ import attrs
 import typing_extensions as te
 
 from acconeer.exptool.a121._core.entities import ServerLogMessage
-from acconeer.exptool.a121._core.mediators import AgnosticClientFriends, Message
+from acconeer.exptool.a121._core.peripherals.communication.message import Message
 
 from .parse_error import ParseError
 
@@ -33,9 +33,6 @@ class LogMessageHeader(te.TypedDict):
 class LogMessage(Message):
     message: ServerLogMessage
 
-    def apply(self, client: AgnosticClientFriends) -> None:
-        client._log_queue.append(self.message)
-
     @classmethod
     def parse(cls, header: t.Dict[str, t.Any], payload: bytes) -> LogMessage:
         t.cast(LogMessageHeader, header)
