@@ -74,6 +74,21 @@ class A121BackendPluginBase(Generic[T], BackendPlugin[T]):
     def load_from_record_setup(self, *, record: a121.H5Record) -> None:
         pass
 
+    @is_task
+    def load_from_cache(self) -> None:
+        try:
+            with self.h5_cache_file() as f:
+                self._load_from_cache(f)
+        except FileNotFoundError:
+            pass
+
+        self._sync_sensor_ids()
+        self.broadcast(sync=True)
+
+    @abc.abstractmethod
+    def _load_from_cache(self, file: h5py.File) -> None:
+        pass
+
     @abc.abstractmethod
     def get_next(self) -> None:
         pass
@@ -101,7 +116,7 @@ class A121BackendPluginBase(Generic[T], BackendPlugin[T]):
             return False
 
     @property
-    def client(self) -> Optional[a121.Client]:
+    def client(self) -> Optional[a121.ClientBase]:
         if self._replaying_client is not None:
             return self._replaying_client
 
@@ -114,6 +129,7 @@ class A121BackendPluginBase(Generic[T], BackendPlugin[T]):
     def attach_client(self, *, client: a121.Client) -> None:
         self._live_client = client
         self._sync_sensor_ids()
+        self.broadcast(True)
 
     def detach_client(self) -> None:
         self._live_client = None
@@ -183,6 +199,19 @@ class A121BackendPluginBase(Generic[T], BackendPlugin[T]):
             self._opened_record = None
             self._replaying_client = None
 
+    def teardown(self) -> None:
+        try:
+            with self.h5_cache_file(write=True) as file:
+                self.save_to_cache(file)
+        except Exception:
+            log.warning("Could not write to cache")
+
+        self.detach_client()
+
+    @abc.abstractmethod
+    def save_to_cache(self, file: h5py.File) -> None:
+        pass
+
 
 class A121ViewPluginBase(ViewPluginBase):
     pass
