@@ -8,6 +8,7 @@ from enum import Enum, auto
 from typing import Callable, Mapping, Optional
 
 import attrs
+import h5py
 import numpy as np
 import qtawesome as qta
 
@@ -32,6 +33,7 @@ from acconeer.exptool.app.new import (
     GridGroupBox,
     HandledException,
     Message,
+    MiscErrorView,
     PidgetFactoryMapping,
     PluginFamily,
     PluginGeneration,
@@ -82,17 +84,9 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
         self.restore_defaults()
 
-    @is_task
-    def load_from_cache(self) -> None:
-        try:
-            with self.h5_cache_file() as f:
-                self.shared_state.config = DetectorConfig.from_json(f["config"][()])
-                self.shared_state.context = DetectorContext.from_h5(f["context"])
-        except FileNotFoundError:
-            pass
-
-        self._sync_sensor_ids()
-        self.broadcast(sync=True)
+    def _load_from_cache(self, file: h5py.File) -> None:
+        self.shared_state.config = DetectorConfig.from_json(file["config"][()])
+        self.shared_state.context = DetectorContext.from_h5(file["context"])
 
     @is_task
     def restore_defaults(self) -> None:
@@ -103,6 +97,10 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         if self.client is not None:
             sensor_ids = self.client.server_info.connected_sensors
 
+            # Try to use the sensor ids from the last calibration
+            if self.shared_state.context.sensor_ids:
+                self.shared_state.sensor_ids = self.shared_state.context.sensor_ids
+
             for i in range(len(self.shared_state.sensor_ids)):
                 if len(sensor_ids) > 0 and self.shared_state.sensor_ids[i] not in sensor_ids:
                     self.shared_state.sensor_ids[i] = sensor_ids[0]
@@ -123,16 +121,10 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.shared_state.config = preset_config()
         self.broadcast(sync=True)
 
-    def teardown(self) -> None:
-        try:
-            with self.h5_cache_file(write=True) as f:
-                _create_h5_string_dataset(f, "config", self.shared_state.config.to_json())
-                context_group = f.create_group("context")
-                self.shared_state.context.to_h5(context_group)
-        except Exception:
-            self._log.warning("Detector could not write to cache")
-
-        self.detach_client()
+    def save_to_cache(self, file: h5py.File) -> None:
+        _create_h5_string_dataset(file, "config", self.shared_state.config.to_json())
+        context_group = file.create_group("context")
+        self.shared_state.context.to_h5(context_group)
 
     def load_from_record_setup(self, *, record: a121.H5Record) -> None:
         algo_group = record.get_algo_group(self.key)
@@ -333,7 +325,6 @@ class ViewPlugin(DetectorViewPluginBase):
 
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
         super().__init__(app_model=app_model, view_widget=view_widget)
-        self.app_model = app_model
         self._log = logging.getLogger(__name__)
 
         sticky_layout = QVBoxLayout()
@@ -385,6 +376,9 @@ class ViewPlugin(DetectorViewPluginBase):
 
         sticky_layout.addWidget(button_group)
 
+        self.misc_error_view = MiscErrorView(self.scrolly_widget)
+        scrolly_layout.addWidget(self.misc_error_view)
+
         sensor_selection_group = VerticalGroupBox("Sensor selection", parent=self.scrolly_widget)
         self.sensor_id_pidget = pidgets.SensorIdParameterWidgetFactory(items=[]).create(
             parent=sensor_selection_group
@@ -395,7 +389,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
         self.config_editor = AttrsConfigEditor[DetectorConfig](
             title="Detector parameters",
-            factory_mapping=self._get_pidget_mapping(),
+            factory_mapping=self.get_pidget_mapping(),
             parent=self.scrolly_widget,
         )
         self.config_editor.sig_update.connect(self._on_config_update)
@@ -405,7 +399,7 @@ class ViewPlugin(DetectorViewPluginBase):
         self.scrolly_widget.setLayout(scrolly_layout)
 
     @classmethod
-    def _get_pidget_mapping(cls) -> PidgetFactoryMapping:
+    def get_pidget_mapping(cls) -> PidgetFactoryMapping:
         return {
             "start_m": pidgets.FloatParameterWidgetFactory(
                 name_label_text="Range start",
@@ -481,10 +475,18 @@ class ViewPlugin(DetectorViewPluginBase):
             ),
         }
 
+    def on_backend_state_update(self, backend_plugin_state: Optional[SharedState]) -> None:
+        if backend_plugin_state is not None and backend_plugin_state.config is not None:
+            results = backend_plugin_state.config._collect_validation_results()
+
+            not_handled = self.config_editor.handle_validation_results(results)
+
+            not_handled = self.misc_error_view.handle_validation_results(not_handled)
+
+            assert not_handled == []
+
     def on_app_model_update(self, app_model: AppModel) -> None:
         state = app_model.backend_plugin_state
-        self.sensor_id_pidget.update_available_sensor_list(app_model._a121_server_info)
-
         if state is None:
             self.start_button.setEnabled(False)
             self.calibrate_detector_button.setEnabled(False)
@@ -493,7 +495,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
             self.config_editor.set_data(None)
             self.config_editor.setEnabled(False)
-            self.sensor_id_pidget.set_parameter(None)
+            self.sensor_id_pidget.set_selected_sensor(None, [])
             self.message_box.setText("")
 
             return
@@ -506,7 +508,7 @@ class ViewPlugin(DetectorViewPluginBase):
         self.config_editor.set_data(state.config)
 
         (sensor_id,) = state.sensor_ids
-        self.sensor_id_pidget.set_parameter(sensor_id)
+        self.sensor_id_pidget.set_selected_sensor(sensor_id, app_model.connected_sensors)
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
         detector_status = Detector.get_detector_status(
@@ -524,11 +526,9 @@ class ViewPlugin(DetectorViewPluginBase):
     def _on_sensor_id_update(self, sensor_id: int) -> None:
         self.app_model.put_backend_plugin_task("update_sensor_ids", {"sensor_ids": [sensor_id]})
 
-    # TODO: move to detector base (?)
     def _on_config_update(self, config: DetectorConfig) -> None:
         self.app_model.put_backend_plugin_task("update_config", {"config": config})
 
-    # TODO: move to detector base (?)
     def handle_message(self, message: GeneralMessage) -> None:
         if message.name == "sync":
             self._log.debug(f"{type(self).__name__} syncing")
@@ -537,20 +537,6 @@ class ViewPlugin(DetectorViewPluginBase):
         else:
             raise RuntimeError("Unknown message")
 
-    # TODO: move to detector base (?)
-    def _send_start_request(self) -> None:
-        self.app_model.put_backend_plugin_task(
-            "start_session",
-            {"with_recorder": self.app_model.recording_enabled},
-            on_error=self.app_model.emit_error,
-        )
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
-
-    # TODO: move to detector base (?)
-    def _send_stop_request(self) -> None:
-        self.app_model.put_backend_plugin_task("stop_session", on_error=self.app_model.emit_error)
-        self.app_model.set_plugin_state(PluginState.LOADED_STOPPING)
-
     def _on_calibrate_detector(self) -> None:
         self.app_model.put_backend_plugin_task(
             "calibrate_detector", on_error=self.app_model.emit_error
