@@ -8,6 +8,7 @@ from enum import Enum, auto
 from typing import Callable, Mapping, Optional
 
 import attrs
+import h5py
 import numpy as np
 import qtawesome as qta
 
@@ -19,7 +20,7 @@ import pyqtgraph as pg
 import acconeer.exptool as et
 from acconeer.exptool import a121
 from acconeer.exptool.a121._h5_utils import _create_h5_string_dataset
-from acconeer.exptool.a121.algo._base import AlgoConfigBase
+from acconeer.exptool.a121.algo._base import AlgoBase
 from acconeer.exptool.a121.algo._plugins import (
     DetectorBackendPluginBase,
     DetectorPlotPluginBase,
@@ -33,6 +34,7 @@ from acconeer.exptool.app.new import (
     GeneralMessage,
     GridGroupBox,
     Message,
+    MiscErrorView,
     PidgetFactoryMapping,
     PluginFamily,
     PluginGeneration,
@@ -48,7 +50,7 @@ from ._detector import Detector, DetectorConfig, DetectorResult, _load_algo_data
 
 
 @attrs.mutable(kw_only=True)
-class PlotConfig(AlgoConfigBase):
+class PlotConfig(AlgoBase):
     number_of_zones: Optional[int] = attrs.field(default=None)
 
 
@@ -80,17 +82,9 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
         self.restore_defaults()
 
-    @is_task
-    def load_from_cache(self) -> None:
-        try:
-            with self.h5_cache_file() as f:
-                self.shared_state.config = DetectorConfig.from_json(f["config"][()])
-                self.shared_state.plot_config = PlotConfig.from_json(f["plot_config"][()])
-        except FileNotFoundError:
-            pass
-
-        self._sync_sensor_ids()
-        self.broadcast(sync=True)
+    def _load_from_cache(self, file: h5py.File) -> None:
+        self.shared_state.config = DetectorConfig.from_json(file["config"][()])
+        self.shared_state.plot_config = PlotConfig.from_json(file["plot_config"][()])
 
     @is_task
     def restore_defaults(self) -> None:
@@ -119,17 +113,9 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.shared_state.config = config
         self.broadcast()
 
-    def teardown(self) -> None:
-        try:
-            with self.h5_cache_file(write=True) as f:
-                _create_h5_string_dataset(f, "config", self.shared_state.config.to_json())
-                _create_h5_string_dataset(
-                    f, "plot_config", self.shared_state.plot_config.to_json()
-                )
-        except Exception:
-            self._log.warning("Detector could not write to cache")
-
-        self.detach_client()
+    def save_to_cache(self, file: h5py.File) -> None:
+        _create_h5_string_dataset(file, "config", self.shared_state.config.to_json())
+        _create_h5_string_dataset(file, "plot_config", self.shared_state.plot_config.to_json())
 
     @is_task
     def set_preset(self, preset_id: int) -> None:
@@ -467,7 +453,6 @@ class PlotPlugin(DetectorPlotPluginBase):
 class ViewPlugin(DetectorViewPluginBase):
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
         super().__init__(app_model=app_model, view_widget=view_widget)
-        self.app_model = app_model
         self._log = logging.getLogger(__name__)
 
         sticky_layout = QVBoxLayout()
@@ -507,6 +492,9 @@ class ViewPlugin(DetectorViewPluginBase):
 
         sticky_layout.addWidget(button_group)
 
+        self.misc_error_view = MiscErrorView(self.scrolly_widget)
+        scrolly_layout.addWidget(self.misc_error_view)
+
         sensor_selection_group = VerticalGroupBox("Sensor selection", parent=self.scrolly_widget)
         self.sensor_id_pidget = pidgets.SensorIdParameterWidgetFactory(items=[]).create(
             parent=sensor_selection_group
@@ -664,9 +652,18 @@ class ViewPlugin(DetectorViewPluginBase):
             ),
         }
 
+    def on_backend_state_update(self, backend_plugin_state: Optional[SharedState]) -> None:
+        if backend_plugin_state is not None and backend_plugin_state.config is not None:
+            results = backend_plugin_state.config._collect_validation_results()
+
+            not_handled = self.config_editor.handle_validation_results(results)
+
+            not_handled = self.misc_error_view.handle_validation_results(not_handled)
+
+            assert not_handled == []
+
     def on_app_model_update(self, app_model: AppModel) -> None:
         state = app_model.backend_plugin_state
-        self.sensor_id_pidget.update_available_sensor_list(app_model._a121_server_info)
 
         if state is None:
             self.start_button.setEnabled(False)
@@ -677,7 +674,7 @@ class ViewPlugin(DetectorViewPluginBase):
             self.config_editor.setEnabled(False)
             self.plot_config_editor.set_data(None)
             self.plot_config_editor.setEnabled(False)
-            self.sensor_id_pidget.set_parameter(None)
+            self.sensor_id_pidget.set_selected_sensor(None, [])
 
             return
 
@@ -689,20 +686,18 @@ class ViewPlugin(DetectorViewPluginBase):
         self.config_editor.set_data(state.config)
         self.plot_config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.plot_config_editor.set_data(state.plot_config)
-        self.sensor_id_pidget.set_parameter(state.sensor_id)
+        self.sensor_id_pidget.set_selected_sensor(state.sensor_id, app_model.connected_sensors)
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
         self.start_button.setEnabled(app_model.is_ready_for_session())
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
-    # TODO: move to detector base (?)
     def _on_config_update(self, config: DetectorConfig) -> None:
         self.app_model.put_backend_plugin_task("update_config", {"config": config})
 
     def _on_plot_config_update(self, config: PlotConfig) -> None:
         self.app_model.put_backend_plugin_task("update_plot_config", {"config": config})
 
-    # TODO: move to detector base (?)
     def handle_message(self, message: GeneralMessage) -> None:
         if message.name == "sync":
             self._log.debug(f"{type(self).__name__} syncing")
@@ -711,20 +706,6 @@ class ViewPlugin(DetectorViewPluginBase):
         else:
             raise RuntimeError("Unknown message")
 
-    # TODO: move to detector base (?)
-    def _send_start_request(self) -> None:
-        self.app_model.put_backend_plugin_task(
-            "start_session",
-            {"with_recorder": self.app_model.recording_enabled},
-            on_error=self.app_model.emit_error,
-        )
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
-
-    # TODO: move to detector base (?)
-    def _send_stop_request(self) -> None:
-        self.app_model.put_backend_plugin_task("stop_session", on_error=self.app_model.emit_error)
-        self.app_model.set_plugin_state(PluginState.LOADED_STOPPING)
-
     def _send_defaults_request(self) -> None:
         self.app_model.put_backend_plugin_task("restore_defaults")
 
