@@ -6,6 +6,7 @@ from acconeer.exptool.flash._xc120 import (
     ACCONEER_XC120_BOARD_PROTOCOL_PID,
     ACCONEER_XC120_BOOTLOADER_PID,
     ACCONEER_XC120_EXPLORATION_SERVER_PID,
+    ACCONEER_XC120_EXPLORATION_SERVER_WINUSB_PID,
     BootloaderTool,
 )
 
@@ -14,10 +15,10 @@ PRODUCT_PID_TO_FLASH_MAP = {
     ACCONEER_XC120_BOARD_PROTOCOL_PID: BootloaderTool,
     ACCONEER_XC120_BOOTLOADER_PID: BootloaderTool,
     ACCONEER_XC120_EXPLORATION_SERVER_PID: BootloaderTool,
+    ACCONEER_XC120_EXPLORATION_SERVER_WINUSB_PID: BootloaderTool,
     ACCONEER_XM_CP2105_MODULE_PID: Stm32UartFlasher,
 }
 
-
 PRODUCT_NAME_TO_FLASH_MAP = {
     "XC120": BootloaderTool,
     "XE125": Stm32UartFlasher,
